==> intel-graphics-compiler_1.0.3627.orig.tar.gz: intel-graphics-compiler-igc-1.0.3627/IGC/common/debug/TeeOutputStream.hpp <==
/*===================== begin_copyright_notice ==================================

Copyright (c) 2017 Intel Corporation

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


======================= end_copyright_notice ==================================*/

#pragma once

#include "common/LLVMWarningsPush.hpp"
#include <llvm/Support/raw_ostream.h>
#include "common/LLVMWarningsPop.hpp"

namespace IGC
{
namespace Debug
{
    class TeeOutputStream
        : public llvm::raw_ostream
    {
    public:
        TeeOutputStream(
            llvm::raw_ostream& s0,
            llvm::raw_ostream& s1);

        TeeOutputStream(
            llvm::raw_ostream* pLHS,
            bool shouldDeleteLHS,
            llvm::raw_ostream* pRHS,
            bool shouldDeleteRHS);

        ~TeeOutputStream();

        size_t preferred_buffer_size() const override;

        llvm::raw_ostream &changeColor(enum llvm::raw_ostream::Colors colors, bool bold, bool bg) override;

        llvm::raw_ostream &resetColor() override;

        llvm::raw_ostream &reverseColor() override;

    private:
        void write_impl(const char *Ptr, size_t Size) override;

        uint64_t current_pos() const override;

    private:
        llvm::raw_ostream*     const m_LHS;
        llvm::raw_ostream*     const m_RHS;
        bool                   const m_deleteLHS;
        bool                   const m_deleteRHS;
    };
} // namespace Debug
} // namespace IGC

==> intel-graphics-compiler_1.0.17791.18.orig.tar.gz: intel-graphics-compiler-igc-1.0.17791.18/IGC/common/debug/TeeOutputStream.hpp <==
/*========================== begin_copyright_notice ============================

Copyright (C) 2017-2021 Intel Corporation

SPDX-License-Identifier: MIT

============================= end_copyright_notice ===========================*/

#pragma once

#include "common/LLVMWarningsPush.hpp"
#include <llvm/Support/raw_ostream.h>
#include "common/LLVMWarningsPop.hpp"

namespace IGC
{
namespace Debug
{
    class TeeOutputStream
        : public llvm::raw_ostream
    {
    public:
        TeeOutputStream(
            llvm::raw_ostream& s0,
            llvm::raw_ostream& s1);

        TeeOutputStream(
            llvm::raw_ostream* pLHS,
            bool shouldDeleteLHS,
            llvm::raw_ostream* pRHS,
            bool shouldDeleteRHS);

        ~TeeOutputStream();
        TeeOutputStream(const TeeOutputStream&) = delete;
        TeeOutputStream& operator=(const TeeOutputStream&) = delete;

        size_t preferred_buffer_size() const override;

        llvm::raw_ostream &changeColor(enum llvm::raw_ostream::Colors colors, bool bold, bool bg) override;

        llvm::raw_ostream &resetColor() override;

        llvm::raw_ostream &reverseColor() override;

    private:
        void write_impl(const char *Ptr, size_t Size) override;

        uint64_t current_pos() const override;

    private:
        llvm::raw_ostream*     const m_LHS;
        llvm::raw_ostream*     const m_RHS;
        bool                   const m_deleteLHS;
        bool                   const m_deleteRHS;
    };
} // namespace Debug
} // namespace IGC
